###Análise de sinal filogenético na pigmentação visceral num conjunto de 28 espécies de anuros
**********************************************************************************************

#PACOTES NECESSÁRIOS
library(ape)
library(ade4)


#IMPORTAÇÃO DOS DADOS  

  #IMPORTA A FILOGENIA CONSTRUIDA NO MESQUITE

filog.new="(((((Ischnocnema_guentheri,Ischnocnema_parva),Ischnocnema_juipoca),Holoaden_leuderwaldti),Haddadus_binotatus),((((Scinax_similis,Scinax_fuscovarius),Scinax_fuscomarginatus),(Dendropsophus_minutus,(Dendropsophus_elianeae,(Dendropsophus_nanus,Dendropsophus_sanborni)))),(((Leptodactylus_bokermani,Leptodactylus_mamoratus),((Leptodactylus_podicipinus,(Leptodactylus_chaquensis,Leptodactylus_latrans)),(Leptodactylus_labyrinthicus,((Leptodactylus_fuscus,Leptodactylus_mystacinus),(Leptodactylus_mystaceus,Leptodactylus_furnarius))))),((Odontophrynus_americanus,(Proceratophrys_boiei,Proceratophrys_melanopogon)),(((Pseudopaludicola_cf._falcipes,Pseudopaludicola_saltica),(Eupemphix_nattereri,(Physalemus_marmoratus,(Physalaemus_olfersii,(Physalemus_cuvieri,Physalaemus_centralis))))),(Hylodes_sazimai,(Crossodactylus_caramaschi,Crossodactylus_gaudichaudii)))))));"
class(filog.new)

mel.phy=newick2phylog(filog.new) #converte a árvore para formato phylog
class(mel.phy)
plot(mel.phy)

#CALCULANDO SINAL FILOGENÉTICO PELO MÉTODO ABOUHEIF
phylo.signal=as.phylo(mel.phy)
filog.len=compute.brlen(phylo.signal, method="Graffen")#atribui comprimento de ramo à árvore
dist.signal=proxTips(filog.len,filog.len$tip.label, "oriAbouheif")
abouheif.moran(pig.org, W=dist.signal, "oriAbouheif")


#IMPORTA A MATRIZ DE ATRIBUTOS (=PIGMENTAÇÃO)
pig.org=read.table(file.choose(), h=T)

#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist=dist.ktab(ktab.list.df(list(pig.org)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist)#testa se a matriz contém distâncias euclidianas
trait.dist

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
source("SUPFILEAc.R")#Carrega a função que realiza os testes
decompos=decdiv(mel.phy, rep(1, 35), trait.dist)
decompos

dev1=rtest.decdiv(mel.phy, rep(1, 35), trait.dist)
dev1
#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o conjunto de todos os órgãos, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos órgãos

plot(dev1)
plot.decdiv(mel.phy, vnodes = decompos)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_orgaos.txt")
dev1
sink()

#PARA TESTÍCULO

pig.test=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.test=dist.ktab(ktab.list.df(list(pig.test)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.test)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
decompos.test=decdiv(mel.phy, rep(1, 35), trait.dist.test)

dev2=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.test)
#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot(dev2)
plot.decdiv(mel.phy, vnodes = decompos.test)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_testiculo.txt")
dev2
sink()


#Para coluna
pig.col=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.col=dist.ktab(ktab.list.df(list(pig.col)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.col)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.col=decdiv(mel.phy, rep(1, 35), trait.dist.col)

dev3=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.col)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.col)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_coluna.txt")
dev3
sink()

#PARA RETO
pig.reto=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.reto=dist.ktab(ktab.list.df(list(pig.reto)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.reto)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.reto=decdiv(mel.phy, rep(1, 35), trait.dist.reto)

dev4=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.reto)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.reto)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_reto.txt")
dev4
sink()

#PARA CORAÇÃO
pig.cor=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.cor=dist.ktab(ktab.list.df(list(pig.cor)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.cor)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.cor=decdiv(mel.phy, rep(1, 35), trait.dist.cor)

dev5=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.cor)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.cor)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_coracao.txt")
dev5
sink()

#PARA MESENTÉRIO
pig.mes=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.mes=dist.ktab(ktab.list.df(list(pig.mes)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.mes)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.mes=decdiv(mel.phy, rep(1, 35), trait.dist.mes)

dev6=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.mes)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.mes)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_mesenterio.txt")
dev6
sink()

#PARA NERVOS
pig.ner=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.ner=dist.ktab(ktab.list.df(list(pig.ner)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.ner)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.ner=decdiv(mel.phy, rep(1, 35), trait.dist.ner)

dev7=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.ner)
#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.ner)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_nervos.txt")
dev7
sink()

#PARA PERICARDIO
pig.per=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.per=dist.ktab(ktab.list.df(list(pig.per)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.per)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.per=decdiv(mel.phy, rep(1, 35), trait.dist.per)

dev8=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.per)
#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.per)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_pericardio.txt")
dev8
sink()

#PARA PERITONIO
pig.perit=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.perit=dist.ktab(ktab.list.df(list(pig.perit)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.perit)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.perit=decdiv(mel.phy, rep(1, 35), trait.dist.perit)

dev9=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.perit)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.perit)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_peritonio.txt")
dev9
sink()

#PARA PULMÃO
pig.pul=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.pul=dist.ktab(ktab.list.df(list(pig.pul)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.pul)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.pul=decdiv(mel.phy, rep(1, 35), trait.dist.pul)

dev10=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.pul)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.pul)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_pulmao.txt")
dev10
sink()

#PARA RINS
pig.rin=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.rin=dist.ktab(ktab.list.df(list(pig.rin)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.rin)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.rin=decdiv(mel.phy, rep(1, 35), trait.dist.rin)

dev11=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.rin)
#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.rin)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_rins.txt")
dev11
sink()

#PARA VASOS
pig.vas=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.vas=dist.ktab(ktab.list.df(list(pig.vas)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.vas)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.vas=decdiv(mel.phy, rep(1, 35), trait.dist.vas)

dev12=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.vas)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.vas)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_vasos.txt")
dev12
sink()


#PARA VEIAS
pig.vei=read.table(file.choose(), h=T)
#CRIANDO A MATRIZ DE DISTÂNCIA COM OS ATRIBUTOS
trait.dist.vei=dist.ktab(ktab.list.df(list(pig.vei)), type="O", scan=T)
#Nas opções que surgem, escolher 1 (ranked variables treated as quantitative) e em seguida 1 (Euclidian)
is.euclid(trait.dist.vei)#testa se a matriz contém distâncias euclidianas

#DECOMPONDO A DIVERSIDADE DE ATRIBUTOS NA FILOGENIA
dec.vei=decdiv(mel.phy, rep(1, 35), trait.dist.vei)

dev13=rtest.decdiv(mel.phy, rep(1, 35), trait.dist.vei)

#Interpretação: Existe sinal filogenético (=autocorrelação filogenética) qdo se considera o testículo, ou seja, espécies mais próximas tendem a exibir as mesmas categorias de pigmentação nos testículo

plot.decdiv(mel.phy, vnodes = dec.vei)

#EXPORTAÇÃO DOS RESULTADOS QUANTITATIVOS
sink("resultados_veias.txt")
dev13
sink()